@@ -16,7 +16,7 @@ gender_kantrowitz <- function(name) {
   # An internal function to predict the gender of one name
   apply_kantrowitz <- function(n) {
 
-    results <- kantrowitz %>% filter(name == n)
+    results <- kantrowitz %>% filter(name == tolower(n))
 
     # If the name isn't in the data set, return use that information rather than
     # silently dropping a row
@@ -24,6 +24,9 @@ gender_kantrowitz <- function(name) {
       results <- data.frame(name = n, gender = NA)
     }
 
+    # Use the original capitalization of the name
+    results$name <- n
+
     return(as.list(results))
 
   }
